==> yst-wms-connector-sdk-zyyy-2.0.21-20251101.082714-1-sources.jar: com/elitesland/yst/wms/connector/client/api/request/EntryorderRequest.java <==
package com.elitesland.yst.wms.connector.client.api.request;

import com.elitesland.yst.wms.connector.client.api.YstWmsRequest;
import com.elitesland.yst.wms.connector.client.api.response.EntryorderConfirmResponse;
import com.elitesland.yst.wms.connector.client.api.response.EntryorderResponse;
import com.taobao.api.ApiRuleException;
import com.taobao.api.internal.mapping.ApiField;
import com.taobao.api.internal.mapping.ApiListField;
import com.taobao.api.internal.mapping.ApiListType;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;

/**
 * TOP API: taobao.qimen.entryorder.confirm request
 * 
 * @author top auto create
 * @since 1.0, 2024.01.23
 */
@Data
public class EntryorderRequest extends YstWmsRequest<EntryorderResponse> {
    // 表头(基本信息)
    @ApiModelProperty("到货通知单号")
    private String ssDocNo;

    @ApiModelProperty("WMS入库单号")
    private String wmsIdoId;

    @ApiModelProperty("仓库编码")
    private String whCode;

    @ApiModelProperty("入库单类型")
    private String idoType;

    @ApiModelProperty("客商编码")
    private String enterpriseCode;

    // 行项目(收货验收明细信息)
    @ApiModelProperty("明细")
    private List<InvPurLdoConfirmGrQtDtlParam> invPurLdoConfirmSsLdoDtlParams;

    @Data
    public static class InvPurLdoConfirmGrQtDtlParam {

        @ApiModelProperty("商品编码")
        private String itemCode;

        @ApiModelProperty("商品名称")
        private String itemName;

        @ApiModelProperty("规格型号")
        private String spec;

        @ApiModelProperty("浓度规格")
        private String concSpec;

        @ApiModelProperty("条码")
        private String barcode;

        @ApiModelProperty("收货数量")
        private Double qty;

        @ApiModelProperty("拒收数")
        private Double rejectQty;

        @ApiModelProperty("合格数")
        private Double okQty;

        @ApiModelProperty("不合格数")
        private Double noQty;

        @ApiModelProperty("单位")
        private String uom;

        @ApiModelProperty("批次号")
        private String lotNo;

        @ApiModelProperty("生产日期")
        private LocalDate manuDate;

        @ApiModelProperty("有效期至")
        private LocalDate expireDate;

        @ApiModelProperty("生产厂家")
        private String manuFactory;

        @ApiModelProperty("批准文号\\备案证号\\注册证号")
        private String approvalNumber;

        @ApiModelProperty("产地")
        private String origin;

        @ApiModelProperty("剂型")
        private String dosageForm;

        @ApiModelProperty("行号")
        private Double lineNo;

        @ApiModelProperty("入库日期")
        private LocalDate wmsDate;

        @ApiModelProperty("产品批号")
        private String productNo;

        @ApiModelProperty("入库数辅助单位")
        private String uom2;

        @ApiModelProperty("拒收原因")
        private String rejectReason;
    }


    @Override
    public String getApiMethodName() {
        return "entryorder.confirm request";
    }

    @Override
    public Class<EntryorderResponse> getResponseClass() {
        return EntryorderResponse.class;
    }
}

==> yst-wms-connector-sdk-zyyy-2.0.29-20251128.034414-1-sources.jar: com/elitesland/yst/wms/connector/client/api/request/EntryorderRequest.java <==
package com.elitesland.yst.wms.connector.client.api.request;

import com.elitesland.yst.wms.connector.client.api.YstWmsRequest;
import com.elitesland.yst.wms.connector.client.api.response.EntryorderConfirmResponse;
import com.elitesland.yst.wms.connector.client.api.response.EntryorderResponse;
import com.taobao.api.ApiRuleException;
import com.taobao.api.internal.mapping.ApiField;
import com.taobao.api.internal.mapping.ApiListField;
import com.taobao.api.internal.mapping.ApiListType;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;

/**
 * TOP API: taobao.qimen.entryorder.confirm request
 * 
 * @author top auto create
 * @since 1.0, 2024.01.23
 */
@Data
public class EntryorderRequest extends YstWmsRequest<EntryorderResponse> {
    // 表头(基本信息)
    @ApiModelProperty("到货通知单号")
    private String ssDocNo;

    @ApiModelProperty("WMS入库单号")
    private String wmsIdoId;

    @ApiModelProperty("仓库编码")
    private String whCode;

    @ApiModelProperty("入库单类型")
    private String idoType;

    @ApiModelProperty("客商编码")
    private String enterpriseCode;

    @ApiModelProperty("执行步骤-可用于重试提交,默认可以不填写,从头执行.填写了根据步骤可以跳过已经执行的数据")
    private Integer steps=1;

    // 行项目(收货验收明细信息)
    @ApiModelProperty("明细")
    private List<InvPurLdoConfirmGrQtDtlParam> invPurLdoConfirmSsLdoDtlParams;

    @Data
    public static class InvPurLdoConfirmGrQtDtlParam {

        @ApiModelProperty("商品编码")
        private String itemCode;

        @ApiModelProperty("商品名称")
        private String itemName;

        @ApiModelProperty("规格型号")
        private String spec;

        @ApiModelProperty("浓度规格")
        private String concSpec;

        @ApiModelProperty("条码")
        private String barcode;

        @ApiModelProperty("收货数量")
        private Double qty;

        @ApiModelProperty("拒收数")
        private Double rejectQty;

        @ApiModelProperty("合格数")
        private Double okQty;

        @ApiModelProperty("不合格数")
        private Double noQty;

        @ApiModelProperty("单位")
        private String uom;

        @ApiModelProperty("批次号")
        private String lotNo;

        @ApiModelProperty("生产日期")
        private LocalDate manuDate;

        @ApiModelProperty("有效期至")
        private LocalDate expireDate;

        @ApiModelProperty("生产厂家")
        private String manuFactory;

        @ApiModelProperty("批准文号\\备案证号\\注册证号")
        private String approvalNumber;

        @ApiModelProperty("产地")
        private String origin;

        @ApiModelProperty("剂型")
        private String dosageForm;

        @ApiModelProperty("行号")
        private Long lineNo;

        @ApiModelProperty("SCM明细id")
        private Long scmDId; //必填	行号

        @ApiModelProperty("入库日期")
        private LocalDate wmsDate;

        @ApiModelProperty("产品批号")
        private String productNo;

        @ApiModelProperty("入库数辅助单位")
        private String uom2;

        @ApiModelProperty("拒收原因")
        private String rejectReason;
    }


    @Override
    public String getApiMethodName() {
        return "entryorder.confirm request";
    }

    @Override
    public Class<EntryorderResponse> getResponseClass() {
        return EntryorderResponse.class;
    }
}
